# ##### BEGIN GPL LICENSE BLOCK #####
#
#  This program is free software; you can redistribute it and/or
#  modify it under the terms of the GNU General Public License
#  as published by the Free Software Foundation; either version 2
#  of the License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software Foundation,
#  Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
#
# ##### END GPL LICENSE BLOCK #####

# <pep8-80 compliant>
bl_addon_info = {
    'name': 'Mesh: Set Bevel Weights',
    'author': 'Josh Wedlake',
    'version': '0.1',
    'blender': (2, 5, 3),
    'location': 'ToolShelf Search',
    'description': 'set bevel weights',
    'url': 'http://tube.freefac.org',
    'category': 'Mesh'}

import re
import fnmatch
import bpy
from bpy.props import *

class BevelWeightEdit(bpy.types.Operator):
    
    dialog_width = 250

    def invoke(self, context, event):
        wm = context.manager
        wm.invoke_props_dialog(self, self.dialog_width)
        return {'RUNNING_MODAL'}
    

class SetBevelWeights(BevelWeightEdit):
    '''set bevel weights'''
    bl_idname = "mesh.bevel_weight"
    bl_label = "Set Bevel Weight"
    bl_options = {'REGISTER', 'UNDO'}


    new_weight = FloatProperty(name="Bevel Weight", 
        description="bevel weight")

    def execute(self, context):
        counte=0
        if bpy.context.mode=='EDIT_MESH':
            bpy.ops.object.editmode_toggle()
        for iedge in bpy.context.active_object.data.edges:
            if iedge.select==True:
                iedge.bevel_weight=self.properties.new_weight
                counte+=1

        bpy.ops.object.editmode_toggle()
        #self.report({'OPERATOR'}, 'Reweighted '+str(counte))

        return {'FINISHED'}

    def draw(self, context):
        layout = self.layout
        props = self.properties

        layout.prop(props, "new_weight")

class AverageBevelWeights(bpy.types.Operator):
    '''averages out the selected edges bevels'''
    bl_idname = "mesh.average_bevel_weights"
    bl_label = "Average Bevel Weights"
    bl_options = {'REGISTER', 'UNDO'}

    def invoke(self, context, event):
        counte=0
        sumbevel=0
        if bpy.context.mode=='EDIT_MESH':
            bpy.ops.object.editmode_toggle()
        for iedge in bpy.context.active_object.data.edges:
            if iedge.select==True:
                sumbevel+=iedge.bevel_weight
                counte+=1
        avbevel=sumbevel/counte
        for iedge in bpy.context.active_object.data.edges:
            if iedge.select==True:
                iedge.bevel_weight=avbevel
        bpy.ops.object.editmode_toggle()
        #self.report({'OPERATOR'}, 'Reweighted '+str(counte)+' to '+str(avbevel))
        return {'FINISHED'}

class SelectSameBevelWeights(bpy.types.Operator):
    '''select same bevel weights as selected edge'''
    bl_idname = "mesh.select_same_bevel_weights"
    bl_label = "Select Same Bevel Weights"
    bl_options = {'REGISTER', 'UNDO'}

    def invoke(self, context, event):
        if bpy.context.active_object.data.total_edge_sel!=1:
            #self.report({'OPERATOR'}, 'Needs only one edge to be selected!')
            return {'FINISHED'}

        if bpy.context.mode=='EDIT_MESH':
            bpy.ops.object.editmode_toggle()

        for iedge in bpy.context.active_object.data.edges:
            if iedge.select==True:
                selectweight=iedge.bevel_weight
                break

        counte=0
        for iedge in bpy.context.active_object.data.edges:
            if iedge.bevel_weight==selectweight:
                iedge.select=True
                counte+=1
        bpy.ops.object.editmode_toggle()
        #self.report({'OPERATOR'}, 'Selected '+str(counte))
        return {'FINISHED'}



classes = [SetBevelWeights,
    AverageBevelWeights,
    SelectSameBevelWeights]

def register():
    register = bpy.types.register
    for c in classes:
            register(c)

def unregister():
    unregister = bpy.types.unregister
    for c in classes:
            unregister(c)

if __name__ == "__main__":
    register()